**************************************************
* State do file to analyze Yale CCES survey items*
* From Yale and Berkeley modules                 *
* Gregory Huber, April 2007                      *
**************************************************

pause on
set more off
set memory 1g

**************************************************
* Recode Raw Survey and Election Data            *
**************************************************

quietly do 01_01_SubProgram_Process_ElectionForecastsandOutcome.do
clear

quietly do 01_02_SubProgram_Code_yale_data.do
clear

quietly do 01_03_SubProgram_Code_UCB_data.do
clear

**************************************************
* Load Data, merge in election results           *
**************************************************

use data\yaledata_recoded.dta
gen yalesurvey=1
quietly append using data\ucbdata_recoded.dta
replace yalesurvey=0 if yalesurvey==.
quietly compress

*get local election results
gen fipsindx = real(fips)
joinby fipsindx using data\2000electiondatabyfipsindx.dta, unmatched(master)   

**************************************************
* Recode Survey Data                             *
**************************************************

*state dummies
tab state, gen(sd_)
drop sd_5
encode state, gen(stnum)

*pid 5 as categories
gen pidcat_r2=(pre_pid5==-2)
gen pidcat_r1=(pre_pid5==-1)
gen pidcat_d1=(pre_pid5==1)
gen pidcat_d2=(pre_pid5==2)

replace pidcat_r2=. if pre_pid5==.
replace pidcat_r1=. if pre_pid5==.
replace pidcat_d1=. if pre_pid5==.
replace pidcat_d2=. if pre_pid5==.

label var pidcat_r2 "Strong R"
label var pidcat_r1 "Weak/Lean R"
label var pidcat_d1 "Weak/Lean D"
label var pidcat_d2 "Strong D"

*Create change variables for spending dependent variables

*Note that we exclude folks who report more than $10,000 on pre or post vacation spending
replace post_vacationspend=. if post_vacationspend>10000
replace pre_vacationspend=. if pre_vacationspend>10000
replace post_holidayspend=. if post_holidayspend>10000
replace pre_holidayspend=. if pre_holidayspend>10000

gen post_log_holidayspend=log(1+post_holidayspend)
gen pre_log_holidayspend=log(1+pre_holidayspend)
gen delta_holidayspend=post_log_holidayspend-pre_log_holidayspend

gen post_log_vacationspend=log(1+post_vacationspend)
gen pre_log_vacationspend=log(1+pre_vacationspend)
gen delta_vacationspend=post_log_vacationspend-pre_log_vacationspend

label var delta_holidayspend "Log Change in Holiday Spending"
label var delta_vacationspend "Log Change in Vacation Spending"

*create indicators for lagged dependent variables and drop first category for categorical dependent variables
tab pre_happy, gen(pre_hap_)
drop pre_hap_1

tab pre_hhincomeforecast, gen(pre_hh_)
drop pre_hh_1

tab pre_nationaleconforecast, gen(pre_nef_)
drop pre_nef_1

tab pre_stateeconforecast, gen(pre_sef_)
drop pre_sef_1

*label variables
label var pre_pid7 "7 Point Party ID Scale (-3 Strong Rep. to 3 Strong Dem.)"
label var pre_educ "Education (Scale, 0 to 5)"
label var pre_female "Female (1=yes)"
label var pre_hispanic "Hispanic (1=yes)"
label var pre_black  "Black (1=yes)"
label var pre_unionmem "Union member (1=yes)"
label var pre_income "Income (Scale, 0 to 1)"
label var pre_incomedkna "Income Refused/Don't Know"
label var pre_pid5 "Party ID (Scale,-2=Strong Republican to +2=Strong Democrat)"
label var age "Age (years)"
label var age2 "Age squared"
label var pre_holidayspend "Pre-election holiday spending"
label var post_holidayspend "Post-election holiday spending"
label var pre_vacationspend "Pre-election vacation spending"
label var post_vacationspend "Post-election vacation spending"
label var pre_happy "Pre-election happiness"
label var post_happy "Post-election happiness"
label var pre_hhincomeforecast "Pre-election household income forecast"
label var post_hhincomeforecast "Post-election household income forecast"
label var pre_nationaleconforecast "Pre-election national economy forecast"
label var post_nationaleconforecast "Post-election national economy forecast"
label var pre_stateeconforecast "Pre-election state economy forecast"
label var post_stateeconforecast "Post-election state economy forecast"

*Rename control vars to consistent prefix to simplify subsequent stata code
rename age C_age
rename age2 C_age2
rename pre_female C_female
rename pre_hispanic C_hispanic
rename pre_black C_black
rename pre_unionmem C_union
rename pre_educ C_educ
rename pre_income C_income
rename pre_incomedkna C_incomedkna

**************************************************
* Code in Political Data                         *
**************************************************

***
*Probability governor's office will change. States with no races are coded as 0 uncertanty
***

replace cook_probchange=0 if cook_probchange==.
rename cook_probchange probGovchange
label var probGovchange "cook prob gov party changes"
gen uncertainty=0
replace uncertainty=1 if probGovchange==.5
label var uncertainty "Uncertain Gov. Elec."

***
*This coding of election outcomes just looks at PARTY of governor after election, and treats only uncertain elections as having
*A unique PID effect
***

gen X_DemGov=(postnov=="D")
replace X_DemGov=-1 if postnov=="R"
replace X_DemGov=X_DemGov*govelec

gen X_uncertainty=uncertainty

*Uncertainty x Post-election Dem gov
gen X_Unc_DemGov=uncertainty*X_DemGov
*Uncertainty and Pid
gen X_Unc_pid5=uncertainty*pre_pid5
*Pid x DemGov
gen X_DemGov_Pid=X_DemGov*pre_pid5
*Uncertainty x Pid x DemGov
gen X_Unc_DemGov_Pid=uncertainty*pre_pid5*X_DemGov

label var X_DemGov "Post-election Governor's Party (1=Dem., 0=No elec., -1=Rep.)"
label var X_uncertainty "Uncertain Governor Election"
label var X_Unc_DemGov "Uncertain Governor Election x Post-election Governor's Party"
label var X_Unc_pid5 "Uncertain Governor Election x Party ID"
label var X_DemGov_Pid "Post-election Governor's Party x Party ID"
label var X_Unc_DemGov_Pid "Uncertain Governor Election x Post-election Governor's Party x Party ID"

log using logs\Results.log, text replace

****************************************************************************
****************************************************************************
****************************************************************************
*TABLE 1, summary stats
****************************************************************************
****************************************************************************
****************************************************************************

*run this silly regression to set sample, non-missing covariates
quietly regress pre_pid5 C_age C_female C_black C_hispanic C_union C_educ C_income C_incomedkna if postdisp~=.
quietly gen summforme=e(sample)

replace summforme=. if delta_holidayspend==. & delta_vacationspend==. & pre_happy==. & pre_hhincomeforecast==. & pre_nationaleconforecast==. & pre_stateeconforecast==.
replace summforme=. if post_happy==. & post_hhincomeforecast==. & post_nationaleconforecast==. & post_stateeconforecast==.

summ pre_pid5 C_age C_female C_hispanic C_black C_union C_income C_incomedkna C_educ pre_hhincomeforecast post_hhincomeforecast pre_nationaleconforecast post_nationaleconforecast delta_holidayspend delta_vacationspend pre_happy post_happy pre_stateeconforecast post_stateeconforecast if summforme==1
outsum pre_pid5 C_age C_female C_hispanic C_black C_union C_income C_incomedkna C_educ pre_hhincomeforecast post_hhincomeforecast pre_nationaleconforecast post_nationaleconforecast delta_holidayspend delta_vacationspend pre_happy post_happy pre_stateeconforecast post_stateeconforecast if summforme==1 using logs\Table2.out,  noparen nonotes replace addnote("Summary statistics for CCES participants included in subsequent model specifications (e.g., provided covariate measures and answered at least one dependent variable battery)")

****************************************************************************
****************************************************************************
****************************************************************************
*TABLES 3 and 4
*3 is forecasts
*4 is behavioral measures
****************************************************************************
****************************************************************************
****************************************************************************

*Table 3A
quietly oprobit post_hhincomeforecast pre_hh_* pre_pid5 C_*, cluster(stnum)
quietly gen insample=e(sample)

oprobit post_hhincomeforecast pre_hh_* pre_pid5 if insample==1, cluster(stnum)
outreg using "logs\Table3a.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes replace

oprobit post_hhincomeforecast pre_hh_* pre_pid5 C_*, cluster(stnum)
outreg using "logs\Table3a.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes append
************************
*begin marginal effects*
************************
quietly estsimp oprobit post_hhincomeforecast pre_hh_* pre_pid5 C_*, cluster(stnum) sims(2000) genname(ms_)
quietly setx 0
quietly setx C_educ 2 C_female 1 C_age 48 C_age2 2304 C_income .5714286
setx pre_hh_4 1
simqi, genpr(php_i_1 php_i_2 php_i_3 php_i_4 php_i_5)
setx pre_pid5 2
simqi, genpr(php_d_1 php_d_2 php_d_3 php_d_4 php_d_5)
setx pre_pid5 -2
simqi, genpr(php_r_1 php_r_2 php_r_3 php_r_4 php_r_5)
setx pre_pid5 0
quietly gen base_pr=php_i_4+php_i_5
quietly gen dem_pr=php_d_4+php_d_5
quietly gen rep_pr=php_r_4+php_r_5
quietly gen dem_base_dif=dem_pr-base_pr
quietly gen rep_base_dif=rep_pr-base_pr
quietly gen dem_rep_dif=dem_pr-rep_pr
quietly _pctile base_pr, percentiles(50)
disp r(r1)
quietly _pctile dem_base_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly _pctile rep_base_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly _pctile dem_rep_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
simqi, fd(pr) changex(pre_pid5 -2 2)
quietly drop ms_* php_* base_pr dem_pr rep_pr dem_base_dif rep_base_dif dem_rep_dif
************************
*end marginal effects  *
************************

*-> New DEPVAR

quietly oprobit post_nationaleconforecast pre_nef_* pre_pid5 C_*, cluster(stnum)
replace insample=e(sample)

oprobit post_nationaleconforecast pre_nef_* pre_pid5 if insample==1, cluster(stnum)
outreg using "logs\Table3a.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes append

oprobit post_nationaleconforecast pre_nef_* pre_pid5 C_*, cluster(stnum)
outreg using "logs\Table3a.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes append
************************
*begin marginal effects*
************************
quietly estsimp oprobit post_nationaleconforecast pre_nef_* pre_pid5 C_*, cluster(stnum) sims(2000) genname(ms_)
quietly setx 0
quietly setx C_educ 2 C_female 1 C_age 48 C_age2 2304 C_income .5714286
setx pre_nef_3 1
simqi, genpr(php_i_1 php_i_2 php_i_3 php_i_4 php_i_5)
setx pre_pid5 2
simqi, genpr(php_d_1 php_d_2 php_d_3 php_d_4 php_d_5)
setx pre_pid5 -2
simqi, genpr(php_r_1 php_r_2 php_r_3 php_r_4 php_r_5)
setx pre_pid5 0
quietly gen base_pr=php_i_4+php_i_5
quietly gen dem_pr=php_d_4+php_d_5
quietly gen rep_pr=php_r_4+php_r_5
quietly gen dem_base_dif=dem_pr-base_pr
quietly gen rep_base_dif=rep_pr-base_pr
quietly gen dem_rep_dif=dem_pr-rep_pr
quietly _pctile base_pr, percentiles(50)
disp r(r1)
quietly _pctile dem_base_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly _pctile rep_base_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly _pctile dem_rep_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
simqi, fd(pr) changex(pre_pid5 -2 2)
quietly drop ms_* php_* base_pr dem_pr rep_pr dem_base_dif rep_base_dif dem_rep_dif
************************
*end marginal effects  *
************************

*Table 4A
quietly regress delta_holidayspend pre_pid5 C_*, cluster(stnum)
replace insample=e(sample)

regress delta_holidayspend pre_pid5 if insample==1, cluster(stnum)
outreg using "logs\Table4a.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes replace

regress delta_holidayspend pre_pid5 C_*, cluster(stnum)
outreg using "logs\Table4a.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes append

************************
*begin marginal effects*
************************
quietly estsimp regress delta_holidayspend pre_pid5 C_*, cluster(stnum) sims(2000) genname(ms_)
quietly setx 0
quietly setx C_educ 2 C_female 1 C_age 48 C_age2 2304 C_income .5714286
simqi
simqi, fd(ev) changex(pre_pid5 -2 2)
quietly drop ms_* 

************************
*end marginal effects  *
************************

*-> New DEPVAR

quietly regress delta_vacationspend pre_pid5 C_*, cluster(stnum)
replace insample=e(sample)

regress delta_vacationspend pre_pid5 if insample==1, cluster(stnum)
outreg using "logs\Table4a.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes append

regress delta_vacationspend pre_pid5 C_*, cluster(stnum)
outreg using "logs\Table4a.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes append
************************
*begin marginal effects*
************************
quietly estsimp regress delta_vacationspend pre_pid5 C_*, cluster(stnum) sims(2000) genname(ms_)
quietly setx 0
quietly setx C_educ 2 C_female 1 C_age 48 C_age2 2304 C_income .5714286
simqi
simqi, fd(ev) changex(pre_pid5 -2 2)
quietly drop ms_* 
************************
*end marginal effects  *
************************

*-> New DEPVAR

quietly oprobit post_happy pre_hap_* pre_pid5 C_*, cluster(stnum)
replace insample=e(sample)

oprobit post_happy pre_hap_* pre_pid5 if insample==1, cluster(stnum)
outreg using "logs\Table4a.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes append

oprobit post_happy pre_hap_* pre_pid5 C_*, cluster(stnum)
outreg using "logs\Table4a.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes append

************************
*begin marginal effects*
************************
quietly estsimp oprobit post_happy pre_hap_* pre_pid5 C_*, cluster(stnum) sims(2000) genname(ms_)
quietly setx 0
quietly setx C_educ 2 C_female 1 C_age 48 C_age2 2304 C_income .5714286
quietly setx pre_hap_3 1
quietly simqi, genpr(php_i_1 php_i_2 php_i_3 php_i_4)
quietly setx pre_pid5 2
quietly simqi, genpr(php_d_1 php_d_2 php_d_3 php_d_4)
quietly setx pre_pid5 -2
quietly simqi, genpr(php_r_1 php_r_2 php_r_3 php_r_4)
quietly setx pre_pid5 0
quietly gen base_pr=php_i_3+php_i_4
quietly gen dem_pr=php_d_3+php_d_4
quietly gen rep_pr=php_r_3+php_r_4
quietly gen dem_base_dif=dem_pr-base_pr
quietly gen rep_base_dif=rep_pr-base_pr
quietly gen dem_rep_dif=dem_pr-rep_pr
quietly _pctile base_pr, percentiles(50)
disp r(r1)
quietly _pctile dem_base_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly _pctile rep_base_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly _pctile dem_rep_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
simqi, fd(pr) changex(pre_pid5 -2 2)
quietly drop ms_* php_* base_pr dem_pr rep_pr dem_base_dif rep_base_dif dem_rep_dif
************************
*end marginal effects  *
************************

****************************************************************************
****************************************************************************
****************************************************************************
*Table 5, robustness
****************************************************************************
****************************************************************************
****************************************************************************

*Baseline specification
oprobit post_nationaleconforecast pre_nef_* pre_pid5 C_*, cluster(stnum)
outreg using "logs\Table5.out", se bfmt(fc) bdec(3) tdec(3) ctitle("Baseline model (From Table 2b)") xstat bracket 3aster nonotes replace

*Excluding independents
oprobit post_nationaleconforecast pre_nef_* pre_pid5 C_* if pre_pid5~=0, cluster(stnum)
outreg using "logs\Table5.out", se bfmt(fc) bdec(3) tdec(3) ctitle("Excluding Independents") xstat bracket 3aster nonotes append

*flex pid
oprobit post_nationaleconforecast pre_nef_* pidcat_* C_*, cluster(stnum)
outreg using "logs\Table5.out", se bfmt(fc) bdec(3) tdec(3) ctitle("Flexible Party ID") xstat bracket 3aster nonotes append

*grouping together all sorts of dems and reps
gen demrep=0
replace demrep=1 if pre_pid5==2 | pre_pid5==1
replace demrep=-1 if pre_pid5==-2 | pre_pid5==-1
label var demrep "Democrat (1) Indpt (0) Republican (-1)"
oprobit post_nationaleconforecast pre_nef_* demrep C_*, cluster(stnum)
outreg using "logs\Table5.out", se bfmt(fc) bdec(3) tdec(3) ctitle("Grouping Strong and Weak Partisans") xstat bracket 3aster nonotes append

*7-pt PID specification
oprobit post_nationaleconforecast pre_nef_* pre_pid7 C_*, cluster(stnum)
outreg using "logs\Table5.out", se bfmt(fc) bdec(3) tdec(3) ctitle("7-pt PID Scale") xstat bracket 3aster nonotes append

*Matching analysis
*This code generates the sample and grouping on observables. R code is in separate file.
preserve
drop if post_nationaleconforecast==. | pre_nationaleconforecast==. | C_female==. | C_hispanic==. | C_black==. | C_union==. | C_income==. | C_incomedkna==. | C_educ==. | C_age==.

gen treat_Dem_loose=.
replace treat_Dem_loose=1 if pre_pid5==1 | pre_pid5==2
replace treat_Dem_loose=0 if pre_pid5==-1 | pre_pid5==-2
drop if treat_Dem_loose==.

gen prefor=pre_nationaleconforecast
gen postfor=post_nationaleconforecast

egen exactmatchcv = group(prefor C_female C_hispanic C_black C_union C_income C_incomedkna C_educ)
keep postfor treat_Dem_loose C_age exactmatchcv

outsheet using matching_data_for_R.csv, replace
restore

*Accounting for local partisanship
oprobit post_nationaleconforecast pre_nef_* pre_pid5 C_* dpct2p, cluster(stnum)
outreg using "logs\Table5.out", se bfmt(fc) bdec(3) tdec(3) ctitle("Including a measure of local partisanship") xstat bracket 3aster nonotes append

*State fixed effects
quietly egen obswithinstate=count(post_nationaleconforecast), by(state)
quietly tab state if obswithinstate>=30, gen(state30dum_)
drop state30dum_3

oprobit post_nationaleconforecast pre_nef_* pre_pid5 C_* state30dum_*, cluster(stnum)
outreg using "logs\Table5.out", se bfmt(fc) bdec(3) tdec(3) ctitle("State Fixed Effects (N>30 Obs in State)") xstat bracket 3aster nonotes append
drop state30dum_*

****************************************************************************
****************************************************************************
****************************************************************************
*TABLE b1
*State Election Effects
****************************************************************************
****************************************************************************
****************************************************************************

*These states have too few obs. to estimate state fixed effects
rename sd_13 sx_13
rename sd_20 sx_20
rename sd_50 sx_50
tab state if cookrating=="Toss-up"

oprobit post_stateeconforecast pre_sef_* pre_pid5 X_* C_* sd_*
outreg using "logs\TableB1.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes replace

*certain dem win versus no elec for 4 unit shift in PID
lincom 4*X_DemGov_Pid

*uncertain dem win versus certain dem win for 4 unit shift in PID
lincom 4*X_Unc_DemGov_Pid + 4*X_Unc_pid5

*cumulative, certain
lincom 4*pre_pid5+4*X_DemGov_Pid

*cumulative, uncertain
lincom 4*pre_pid5+4*X_DemGov_Pid+4*X_Unc_DemGov_Pid+4*X_Unc_pid5

************************
*begin marginal effects*
************************
quietly estsimp oprobit post_stateeconforecast pre_sef_* pre_pid5 X_* C_* sd_*, sims(2000) genname(ms_)
quietly setx 0
quietly setx C_educ 2 C_female 1 C_age 48 C_age2 2304 C_income .5714286
setx pre_sef_3 1

*certain dem win
setx X_DemGov 1 X_uncertai 0 X_Unc_DemGov 0
simqi, fd(pr) changex(pre_pid5 -2 2 X_DemGov_Pid -2 2 )

*certain rep win
setx X_DemGov -1 X_uncertai 0 X_Unc_DemGov 0
simqi, fd(pr) changex(pre_pid5 -2 2 X_DemGov_Pid 2 -2 )

*uncertain dem win
setx X_DemGov 1 X_uncertai 1 X_Unc_DemGov 1
simqi, fd(pr) changex(pre_pid5 -2 2 X_DemGov_Pid -2 2 X_Unc_pid5 -2 2 X_Unc_DemGov_Pid -2 2)

*uncertain rep win
setx X_DemGov -1 X_uncertai 1 X_Unc_DemGov -1
simqi, fd(pr) changex(pre_pid5 -2 2 X_DemGov_Pid 2 -2 X_Unc_pid5 -2 2 X_Unc_DemGov_Pid 2 -2)

*uncertain dem win
setx X_DemGov 1 X_uncertai 1 X_Unc_DemGov  1

simqi, genpr(php_i_1 php_i_2 php_i_3 php_i_4 php_i_5)
setx pre_pid5 2 X_Unc_pid5 2 X_DemGov_Pid 2 X_Unc_DemGov_Pid 2
simqi, genpr(php_d_1 php_d_2 php_d_3 php_d_4 php_d_5)
setx pre_pid5 -2 X_Unc_pid5 -2 X_DemGov_Pid -2 X_Unc_DemGov_Pid -2
simqi, genpr(php_r_1 php_r_2 php_r_3 php_r_4 php_r_5)
quietly gen base_pr=php_i_4+php_i_5
quietly gen dem_pr=php_d_4+php_d_5
quietly gen rep_pr=php_r_4+php_r_5
quietly gen dem_base_dif=dem_pr-base_pr
quietly gen rep_base_dif=rep_pr-base_pr
quietly gen dem_rep_dif=dem_pr-rep_pr
quietly _pctile base_pr, percentiles(50)
disp r(r1)
quietly _pctile dem_base_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly _pctile rep_base_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly _pctile dem_rep_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly drop ms_* php_* base_pr dem_pr rep_pr dem_base_dif rep_base_dif dem_rep_dif
************************
*end marginal effects  *
************************

*-> New DEPVAR

oprobit post_nationaleconforecast pre_nef_* pre_pid5 X_* C_* sd_*
outreg using "logs\TableB1.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket 3aster nonotes append

*certain dem win versus no elec for 4 unit shift in PID
lincom 4*X_DemGov_Pid

*uncertain dem win versus certain dem win for 4 unit shift in PID
lincom 4*X_Unc_DemGov_Pid + 4*X_Unc_pid5

*cumulative, certain
lincom 4*pre_pid5+4*X_DemGov_Pid

*cumulative, uncertain
lincom 4*pre_pid5+4*X_DemGov_Pid+4*X_Unc_DemGov_Pid+4*X_Unc_pid5

************************
*begin marginal effects*
************************
quietly estsimp oprobit post_stateeconforecast pre_sef_* pre_pid5 X_* C_* sd_*, sims(2000) genname(ms_)
quietly setx 0
quietly setx C_educ 2 C_female 1 C_age 48 C_age2 2304 C_income .5714286
setx pre_sef_3 1

*certain dem win
setx X_DemGov 1 X_uncertai 0 X_Unc_DemGov 0
simqi, fd(pr) changex(pre_pid5 -2 2 X_DemGov_Pid -2 2 )

*certain rep win
setx X_DemGov -1 X_uncertai 0 X_Unc_DemGov 0
simqi, fd(pr) changex(pre_pid5 -2 2 X_DemGov_Pid 2 -2 )

*uncertain dem win
setx X_DemGov 1 X_uncertai 1 X_Unc_DemGov 1
simqi, fd(pr) changex(pre_pid5 -2 2 X_DemGov_Pid -2 2 X_Unc_pid5 -2 2 X_Unc_DemGov_Pid -2 2)

*uncertain rep win
setx X_DemGov -1 X_uncertai 1 X_Unc_DemGov -1
simqi, fd(pr) changex(pre_pid5 -2 2 X_DemGov_Pid 2 -2 X_Unc_pid5 -2 2 X_Unc_DemGov_Pid 2 -2)

*uncertain dem win
setx X_DemGov 1 X_uncertai 1 X_Unc_DemGov  1

simqi, genpr(php_i_1 php_i_2 php_i_3 php_i_4 php_i_5)
setx pre_pid5 2 X_Unc_pid5 2 X_DemGov_Pid 2 X_Unc_DemGov_Pid 2
simqi, genpr(php_d_1 php_d_2 php_d_3 php_d_4 php_d_5)
setx pre_pid5 -2 X_Unc_pid5 -2 X_DemGov_Pid -2 X_Unc_DemGov_Pid -2
simqi, genpr(php_r_1 php_r_2 php_r_3 php_r_4 php_r_5)
quietly gen base_pr=php_i_4+php_i_5
quietly gen dem_pr=php_d_4+php_d_5
quietly gen rep_pr=php_r_4+php_r_5
quietly gen dem_base_dif=dem_pr-base_pr
quietly gen rep_base_dif=rep_pr-base_pr
quietly gen dem_rep_dif=dem_pr-rep_pr
quietly _pctile base_pr, percentiles(50)
disp r(r1)
quietly _pctile dem_base_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly _pctile rep_base_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly _pctile dem_rep_dif, percentiles(2.5 50 97.5)
disp r(r1) " " r(r2) " " r(r3)
quietly drop ms_* php_* base_pr dem_pr rep_pr dem_base_dif rep_base_dif dem_rep_dif
************************
*end marginal effects  *
************************

log close


